
* ***************************************************************** *
* ***************************************************************** *
*   File-Name:      analyse.do                                      *
*   Date:           July 22, 2015                                   *
*   Author:         TG                                              *
*   Purpose:      	Estimation of regression models including       *
*                   robustness tests for the Appendix               *
*   Input File:     PVSanalyse.dta                                  *
*   Output File:                                                    *
* ****************************************************************  *
* ****************************************************************  *


set more off
use PVSanalyse, clear

keep urteil mein_metr senat adis_loggerreg_kabinett nachtrglich bel_oppreg u_jahr proxy adis_mcssgerreg_kabinett



* Verteiung der AV
logit urteil mein_metr senat adis_loggerreg_kabinett  if nachtrglich==.
tab urteil if e(sample)

pwcorr mein_metr bel_oppreg adis_loggerreg_kabinett, sig star (.1)

corr mein_metr bel_oppreg if e(sample)

*Labels vergeben

lab var mein_metr "Spezifische Untersttzung"
lab var bel_oppreg "Allgemeine Untersttzung"
lab var senat "Senat II (= 1)"
numlabel, add

****Endtabelle - Tabelle 1. Beinhaltet jeweils 2 Modelle fr die spezifische und 2 Modelle fr die diffuse Untersttzung

eststo clear
eststo:logit urteil mein_metr if nachtrglich==. 
estat classification
eststo:logit urteil mein_metr senat adis_loggerreg_kabinett  if nachtrglich==.
estat classification

eststo:logit urteil bel_oppreg if nachtrglich==.
estat classification
eststo:logit urteil bel_oppreg senat adis_loggerreg_kabinett  if nachtrglich==.
estat classification



esttab, compress se pr2 star(* 0.10 ** 0.05 *** 0.01) label noobs, using Endtabelle.rtf, replace   ///
    nonumbers mtitles("(1)" "(2)" "(3)" "(4)") ///
	title(Tabelle 1: Erfolg von Oppositionsantrgen bei abstrakten Normenkontrollverfahren und Bund-Lnder Streitigkeiten in Abhngigkeit von der ffentlichen Meinung, 1974-2010) ///	
addnote("Quelle: Eigene Daten; N = 93.")
eststo clear





**************
** APPENDIX **
**************

*****Tabelle B: Robustheitstest fr Subsamples ohne Proxy

eststo clear
eststo:logit urteil mein_metr if nachtrglich==. & proxy== 0 
estat classification
eststo:logit urteil mein_metr senat adis_loggerreg_kabinett  if nachtrglich==. & proxy== 0 
estat classification

eststo:logit urteil bel_oppreg if nachtrglich==. & proxy== 0 
estat classification
eststo:logit urteil bel_oppreg senat adis_loggerreg_kabinett  if nachtrglich==. & proxy== 0 
estat classification

esttab, compress se pr2 star(* 0.10 ** 0.05 *** 0.01) label noobs, using tabB.rtf, replace   ///
    nonumbers mtitles("(1)" "(2)" "(3)" "(4)") ///
	title(Tabelle B: Robustheitstest fr den Erfolg von Oppositionsantrgen fr den reduzierten Datensatz der nur aus Entscheidungen besteht, in denen die ffentliche Meinung zum Klageinhalt der Opposition ohne Proxy-Fragen erfasst wird.) ///	
addnote("Quelle: Eigene Daten; N = 54.")
eststo clear



********Tabelle C Appendix: ohne Allensbach- Daten

eststo clear
eststo:logit urteil bel_oppreg if nachtrglich==. & u_jahr > 1976 
estat classification
eststo:logit urteil bel_oppreg senat adis_loggerreg_kabinett  if nachtrglich==. & u_jahr > 1976 
estat classification

esttab, compress se pr2 star(* 0.10 ** 0.05 *** 0.01) label noobs, using Robustheitstest_Allensbach.rtf, replace   ///
    nonumbers mtitles("(1)" "(2)") ///
	title(Tabelle C: Robustheitstest fr den Erfolg von Oppositionsantrgen in Abhngigkeit von der allgemeinen Untersttzung (1977-2010) ///
	fr den reduzierten Datensatz ohne die Benutzung von Allensbachdaten.) ///	
addnote("Quelle: Eigene Daten; N = 84.")
eststo clear



***** Tabelle D: Robustheitstest fr andere Positionsmasse (Mcss) zur Berechnung der Distanz

eststo:logit urteil mein_metr senat adis_mcssgerreg_kabinett if nachtrglich==.
estat classification
eststo:logit urteil bel_oppreg senat adis_mcssgerreg_kabinett if nachtrglich==.
estat classification


esttab, compress se pr2 star(* 0.10 ** 0.05 *** 0.01) label noobs, using Robutsheitstest_alternativ.rtf, replace   ///
    nonumbers mtitles("(1)" "(2)" "(3)" "(4)" "(5)" "(6)") ///
	title(Tabelle 1: Erfolg von Oppositionsantrgen bei abstrakten Normenkontrollverfahren und Bund-Lnder Streitigkeiten in Abhngigkeit von der ffentlichen Meinung, 1974-2010) ///	
addnote("Quelle: Eigene Daten; N = 93.")
eststo clear




