
* ***************************************************************** *
* ***************************************************************** *
*   File-Name:      grafiken.do                                     *
*   Date:           July 23, 2015                                   *
*   Author:         TG                                              *
*   Purpose:      	Generates simulations for figure 1 & 2          *
*                   (conditional effects plots)                     * 
* 	Input File:     PVSanalyse.dta                                  *           
*   Data Output:    PVSanalyse.dta                                  *
* ****************************************************************  *
* ****************************************************************  *




set more off
use PVSanalyse, clear



* Verteiung der AV
tab urteil if e(sample)



*Labels vergeben

lab var mein_metr "Spezifische Untersttzung"
lab var bel_oppreg "Allgemeine Untersttzung"
lab var senat "Senat"
numlabel, add



***********************************
* Abbildung 1
* Grafik spezifisch Untersttzung
***********************************

set more off

capture drop b1-b4
capture drop evalaxis pv pi1lo pi1hi
capture drop where* pipe 
capture drop IV



logit urteil mein_metr senat adis_loggerreg_kabinett  if nachtrglich==.
gen IV = mein_metr if e(sample)

set seed 1234
estsimp logit urteil mein_metr senat adis_loggerreg_kabinett  if nachtrglich==.

setx senat 0 adis_loggerreg_kabinett mean mein_metr .15
simqi, prval(0 1)

setx senat 0 adis_loggerreg_kabinett mean mein_metr .70
simqi, prval(0 1)

simqi, fd(pr) changex(mein_metr .15 .70) level(90)



setx senat 0 adis_loggerreg_kabinett mean
simqi, prval(0 1)

generate evalaxis = (_n-1)/100 in 1/100

generate pv=.
generate pi1lo=.
generate pi1hi=.

forvalue a=0.15(.01)0.9 {
   setx mein_metr `a' 
   simqi, prval(1) genpr(pi)
   _pctile pi, p(5,95)
   replace pi1lo = r(r1) if evalaxis==float(`a')
   replace pi1hi = r(r2) if evalaxis==float(`a')
   drop  pi
}
replace pv = pi1hi-(pi1hi-pi1lo)/2

gen where = -0.003 
gen pipe = "|"


*gen where1 = 1.003

#delimit ;
twoway
rarea pi1lo pi1hi evalaxis if evalaxis<=1 , sort bcolor(gs14) ||
line  pv evalaxis if evalaxis<=1 ||
(scatter where IV, ms(none) mlabel(pipe) mlabpos(0))
, legend(off) ytitle("Erfolgswahrscheinlichkeit Oppositionsantrge", color(black)) 
yscale(titlegap(2) range(0 1)) ylabel(0(.5)1,  ticks angle(0)) 
xtitle("Spezifische Untersttzung [in %]", color(black) alignment(bottom )) xscale(titlegap(3) ) 
xlabel(0 "0"  0.1 "10" .2 "20" 0.3 "30" .4 "40" 0.5 "50" .6 "60" .7 "70" 0.8 "80" .9 "90" 1 "100", ticks labels)
xticks(0(0.1)1)
scheme(s1mono) saving(urteil1, replace)
;
#delimit cr

graph export urteil1.png, replace
*graph export urteil1.tif, replace
graph export urteil1.eps, replace
graph export urteil1.pdf, replace

#delimit ;
twoway
rarea pi1lo pi1hi evalaxis if evalaxis<=1 , sort bcolor(gs14) ||
line  pv evalaxis if evalaxis<=1 ||
(scatter where IV, ms(none) mlabel(pipe) mlabpos(0))
, legend(off) ytitle("Probability of Success", color(black)) 
yscale(titlegap(2) range(0 1)) ylabel(0(.5)1,  ticks angle(0)) 
xtitle("Specific Support [in %]", color(black) alignment(bottom )) xscale(titlegap(3) ) 
xlabel(0 "0"  0.1 "10" .2 "20" 0.3 "30" .4 "40" 0.5 "50" .6 "60" .7 "70" 0.8 "80" .9 "90" 1 "100", ticks labels)
xticks(0(0.1)1)
scheme(s1mono) saving(urteil1e, replace)
;
#delimit cr
graph export urteil1e.pdf, replace




set more off


***********************************
* Abbildung 2
* Grafik Allgemeine Untersttzung
***********************************


capture drop b1-b4
capture drop evalaxis pv pi1lo pi1hi
capture drop where* pipe 
capture drop IV1

logit urteil bel_oppreg senat adis_loggerreg_kabinett  if nachtrglich==.
gen IV1 = bel_oppreg if e(sample)

set seed 1234
estsimp logit urteil bel_oppreg senat adis_loggerreg_kabinett  if nachtrglich==. 
setx senat 0 adis_loggerreg_kabinett mean bel_oppreg -1
simqi, prval(0 1)

setx senat 0 adis_loggerreg_kabinett mean bel_oppreg  1
simqi, prval(0 1)

simqi, fd(pr) changex(bel_oppreg  -1 1)


setx senat 0 adis_loggerreg_kabinett mean
simqi, prval(0 1)

generate evalaxis = (_n-1)/100 - 2.1 in 1/381

generate pv=.
generate pi1lo=.
generate pi1hi=.

forvalue a=-2.1(.1)1.7 {
   setx bel_oppreg `a' 
   simqi, prval(1) genpr(pi)
   _pctile pi, p(5,95)
   replace pi1lo = r(r1) if evalaxis==float(`a')
   replace pi1hi = r(r2) if evalaxis==float(`a')
   drop  pi
}
replace pv = pi1hi-(pi1hi-pi1lo)/2

gen where = -0.003 
gen pipe = "|"


#delimit ;
twoway
rarea pi1lo pi1hi evalaxis if evalaxis>-0.9 , sort bcolor(gs14) ||
line  pv evalaxis if evalaxis>-0.9 ||
(scatter where IV1 if IV1>-0.9, ms(none) mlabel(pipe) mlabpos(0)) 
, legend(off) ytitle("Probability of Success", color(black)) 
yscale(titlegap(2) range(0 1)) ylabel(0(.5)1,  ticks angle(0)) 
xtitle("Diffuse Support (Opposition - Government)", color(black) alignment(bottom )) xscale(titlegap(3) ) 
xticks(-1(0.1)1.7) xlabel(-1 0 1 1.7)
scheme(s1mono) saving(urteil2e, replace)
;
#delimit cr

graph export urteil2e.pdf, replace

*xticks(-2.1(0.1)1.7) xlabel(-2.1 0 1.7)

#delimit ;
twoway
rarea pi1lo pi1hi evalaxis if evalaxis>-0.9 , sort bcolor(gs14) ||
line  pv evalaxis if evalaxis>-0.9 ||
(scatter where IV1 if IV1>-0.9, ms(none) mlabel(pipe) mlabpos(0)) 
, legend(off) ytitle("Erfolgswahrscheinlichkeit Oppositionsantrge", color(black)) 
yscale(titlegap(2) range(0 1)) ylabel(0(.5)1,  ticks angle(0)) 
xtitle("Allgemeine Untersttzung (Opposition - Regierung)", color(black) alignment(bottom )) xscale(titlegap(3) ) 
xticks(-1(0.1)1.7) xlabel(-1 0 1 1.7)
scheme(s1mono) saving(urteil2, replace)
;
#delimit cr

graph export urteil2.png, replace
*graph export urteil2.tif, replace
graph export urteil2.eps, replace
graph export urteil2.pdf, replace


exit


