
* ***************************************************************** *
* ***************************************************************** *
*   File-Name:      partyscores.do                                  *
*   Date:           July 23, 2015                                   *
*   Author:         TG                                              *
*   Purpose:      	Generiert party scores aus Lowe et al (Rile &   *
*                   LogRile) sowie Koenig et al (MCSS) und          *
*                   speichert sie tagesaktuell in partyscores       *
* 	Input File:     MPDS2012b_withSEandLogitSE_Germny.dta & germany.dta                                    
*   Data Output:    partyscores.dta                                *
* ****************************************************************  *
* ****************************************************************  *




* Get logit RiLe scores and SE from Lowe et al replication data
set more off

use MPDS2012b_withSEandLogitSE_Germny, clear
gen year = floor(date/100)

keep if year >= 1972 /* we only need scores in those years */

gen mergeid = year + party/100000

keep mergeid year date party partyname  rile rileSE logrile logrile_SE
order mergeid party year date

sort mergeid
compress
save Loweetal, replace





* get Manifesto Common Space Scores (MCSS) scores from Koenigetal 2013, thanks to Moritz Marbach
use germany, clear
keep if year >= 1972 /* we only need scores in those years */
keep if study==1

egen mcss = rmean(Draw_1-Draw_2000)
label variable mcss "Manifesto Common Space Scores"
egen mcss_sd = rsd(Draw_1-Draw_2000)
label variable mcss_sd "SD of MCSS"

ren  party party_str /* prepare for merging */
destring party_str, generate(party)

gen date = year
label variable date "YYYYMM"
*recode date 1949 = 194908 
*recode date 1953 = 195309 
*recode date 1957 = 195709 
*recode date 1961 = 196109 
*recode date 1965 = 196509 
*recode date 1969 = 196909 
recode date 1972 = 197211 
recode date 1976 = 197610 
recode date 1980 = 198010 
recode date 1983 = 198303 
recode date 1987 = 198701 
recode date 1990 = 199012 
recode date 1994 = 199410 
recode date 1998 = 199809 
recode date 2002 = 200209 
recode date 2005 = 200509 
recode date 2009 = 200909 
 

gen mergeid = year + party/100000
keep mergeid party year date mcss*
order mergeid party year date
sort mergeid
compress 
save Koenigetal, replace


merge 1:1 mergeid using Loweetal
drop _merge mergeid


erase Koenigetal.dta
erase Loweetal.dta

encode partyname, gen (partei)
* Linke is succesor of PDS; Greens and Alliance '90 get the same score
recode partei 4/5=1 /*Greens*/
recode partei 6=8   /*Left Party/PDS*/

gen month = date

recode month 197211 = 11 
recode month 197610 = 10 
recode month 198010 = 10 
recode month 198303 = 03 
recode month 198701 = 01 
recode month 199012 = 12 
recode month 199410 = 10 
recode month 199809 = 09 
recode month 200209 = 09 
recode month 200509 = 09 
recode month 200909 = 09 
 
keep partei year date month mcss mcss_sd rile rileSE logrile logrile_SE


* Create partyscores by party for N=11 critical time points (election dates that define change in govt)

/*
1 90/Greens Alliance '90/Greens	8	
2 CDU/CSU Christian Democratic Union/Social	Union				          
3 FDP Free Democratic Party	
7 SPD Social Democratic Party
8 The Left Party/PDS	          
*/

preserve
keep if partei==1
drop partei
ren mcss       g_mcss       
ren mcss_sd    g_mcss_sd    
ren rile       g_rile       
ren rileSE     g_rileSE     
ren logrile    g_logrile    
ren logrile_SE g_logrile_SE   

label variable g_mcss        "Green MCSS"
label variable g_mcss_sd     "SD of Green MCSS"
label variable g_rile        "Green Rile"
label variable g_rileSE      "SE of Green Rile"
label variable g_logrile     "Green LogRile"
label variable g_logrile_SE  "SE Green LogRile"
compress
sort date year
save g_scores, replace
restore

preserve
keep if partei==2
drop partei
ren mcss       c_mcss  
ren mcss_sd    c_mcss_sd    
ren rile       c_rile   
ren rileSE     c_rileSE  
ren logrile    c_logrile    
ren logrile_SE c_logrile_SE   

label variable c_mcss   "CDU MCSS"
label variable c_mcss_sd    "SD of CDU MCSS"
label variable c_rile    "CDU Rile"
label variable c_rileSE   "SD of CDU Rile"
label variable c_logrile    "CDU LogRile"
label variable c_logrile_SE "SD CDU LogRile"
compress
sort date year
save c_scores, replace
restore

preserve
keep if partei==3
drop partei
ren mcss       f_mcss       
ren mcss_sd    f_mcss_sd    
ren rile       f_rile       
ren rileSE     f_rileSE     
ren logrile    f_logrile    
ren logrile_SE f_logrile_SE   

label variable f_mcss        "FDP MCSS"
label variable f_mcss_sd     "SD of FDP MCSS"
label variable f_rile        "Green Rile"
label variable f_rileSE      "SE of FDP Rile"
label variable f_logrile     "FDP LogRile"
label variable f_logrile_SE  "SE FDP LogRile"
compress
sort date year
save f_scores, replace
restore

preserve
keep if partei==7
drop partei
ren mcss       s_mcss       
ren mcss_sd    s_mcss_sd    
ren rile       s_rile       
ren rileSE     s_rileSE     
ren logrile    s_logrile    
ren logrile_SE s_logrile_SE   

label variable s_mcss        "SPD MCSS"
label variable s_mcss_sd     "SD of SPD MCSS"
label variable s_rile        "SPD Rile"
label variable s_rileSE      "SE of SPD Rile"
label variable s_logrile     "SPD LogRile"
label variable s_logrile_SE  "SE SPD LogRile"
compress
sort date year
save s_scores, replace
restore

preserve
keep if partei==8
drop partei
ren mcss       l_mcss       
ren mcss_sd    l_mcss_sd    
ren rile       l_rile       
ren rileSE     l_rileSE     
ren logrile    l_logrile    
ren logrile_SE l_logrile_SE   

label variable l_mcss        "Linke/PDS MCSS"
label variable l_mcss_sd     "SD of Linke/PDS MCSS"
label variable l_rile        "Linke/PDS Rile"
label variable l_rileSE      "SE of Linke/PDS Rile"
label variable l_logrile     "Linke/PDS LogRile"
label variable l_logrile_SE  "SE Linke/PDS LogRile"
compress
sort date year
save l_scores, replace


restore


/*
variable name   type   format      label      variable label
------------------------------------------------------------------------------------------
g_datum         long   %dD_m_Y                gesetzesdatum
u_datum         long   %dD_m_Y                urteilsdatum
w_datum         long   %dD_m_Y                wahlzeitpunkt
*/


clear
set obs 20000
gen datum = _n
format datum %dD_m_Y /* for merge to PVSdata, expansion of Hnnige Datensatz */
label variable datum "Datum"

keep if datum>= mdy(1, 1, 1972)
keep if datum < mdy(1, 1, 2011)

gen year = year(datum)
gen month = month(datum)
gen day = day(datum)

sort year

/*
197211
197610
198010
198303
198701
199012
199410
199809
200209
200509
200909
*/



* mergen ber date: das muss entsprechend ber datum generiert werden
* Termine Bundestagswahl aus Wikipedia
gen date = .
replace date = 197211 if datum <  mdy(10, 03, 1976)
replace date = 197610 if datum >= mdy(10, 03, 1976) & datum < mdy(10, 05, 1980)
replace date = 198010 if datum >= mdy(10, 05, 1980) & datum < mdy(03, 06, 1983)
replace date = 198303 if datum >= mdy(03, 06, 1983) & datum < mdy(01, 25, 1987)
replace date = 198701 if datum >= mdy(01, 25, 1987) & datum < mdy(12, 02, 1990)
replace date = 199012 if datum >= mdy(12, 02, 1990) & datum < mdy(10, 16, 1994)
replace date = 199410 if datum >= mdy(10, 16, 1994) & datum < mdy(09, 27, 1998)
replace date = 199809 if datum >= mdy(09, 27, 1998) & datum < mdy(09, 22, 2002)
replace date = 200209 if datum >= mdy(09, 22, 2002) & datum < mdy(09, 18, 2005)
replace date = 200509 if datum >= mdy(09, 18, 2005) & datum < mdy(09, 27, 2009)
replace date = 200909 if datum >= mdy(09, 27, 2009)
label variable date "Datum BTW"
sort date

* ber date werden die Parteiepositionen, die zwischen Wahlen konstant sind, tagesgenau zugespielt

* merge in party scores
merge m:1 date using c_scores
drop _merge
merge m:1 date using s_scores
drop _merge
merge m:1 date using f_scores
drop _merge
merge m:1 date using g_scores
drop _merge
merge m:1 date using l_scores
drop _merge
*checked. OK

*Aufrumen
erase c_scores.dta
erase s_scores.dta
erase f_scores.dta
erase g_scores.dta
erase l_scores.dta

gen u_datum = datum
label variable u_datum "urteilsdatum"

sort u_datum
compress
save partyscores, replace

